@@ -11,8 +11,8 @@ add_conf_proc( 'default', '' ) do
       <p>ʤ̾ꤷޤ</p>
       <p><input name="author_name" value="#{CGI::escapeHTML(@conf.author_name)}" size="40"></p>
       <h3 class="subtitle">᡼륢ɥ쥹</h3>
-      <p>ʤΥ᡼륢ɥ쥹ꤷޤ</p>
-      <p><input name="mail" value="#{CGI::escapeHTML(@conf.mail)}" size="40"></p>
+      <p>ʤΥ᡼륢ɥ쥹ꤷޤ1Ԥ1ɥ쥹Ļꤷޤ</p>
+      <p><textarea name="mail" rows="4" cols="50">#{CGI::escapeHTML(@conf.mail.join("\n"))}</textarea></p>
       <h3 class="subtitle">᡼</h3>
       <p>ڡιä˥᡼Τ뤫ɤꤷޤ᡼ϴǻꤷɥ쥹ޤ餫hikiconf.rbSMTPФꤷƤƤ</p>
       <p><select name="mail_on_update">
